@@ -1,13 +1,7 @@
 import os
+from unittest import mock
 
 import pytest
-from dagster_aws.s3 import s3_plus_default_intermediate_storage_defs, s3_resource
-from dagster_azure.adls2 import adls2_plus_default_intermediate_storage_defs, adls2_resource
-from dagster_databricks import databricks_pyspark_step_launcher
-from dagster_pyspark import DataFrame, pyspark_resource
-from pyspark.sql import Row
-from pyspark.sql.types import IntegerType, StringType, StructField, StructType
-
 from dagster import (
     InputDefinition,
     ModeDefinition,
@@ -18,8 +12,13 @@ from dagster import (
     solid,
 )
 from dagster.core.definitions.no_step_launcher import no_step_launcher
-from dagster.seven import mock
 from dagster.utils.merger import deep_merge_dicts
+from dagster_aws.s3 import s3_plus_default_intermediate_storage_defs, s3_resource
+from dagster_azure.adls2 import adls2_plus_default_intermediate_storage_defs, adls2_resource
+from dagster_databricks import databricks_pyspark_step_launcher
+from dagster_pyspark import DataFrame, pyspark_resource
+from pyspark.sql import Row
+from pyspark.sql.types import IntegerType, StringType, StructField, StructType
 
 S3_BUCKET = "dagster-databricks-tests"
 ADLS2_STORAGE_ACCOUNT = "dagsterdatabrickstests"
@@ -36,7 +35,9 @@ BASE_DATABRICKS_PYSPARK_STEP_LAUNCHER_CONFIG = {
             "new": {
                 "size": {"num_workers": 1},
                 "spark_version": "6.5.x-scala2.11",
-                "nodes": {"node_types": {"node_type_id": "Standard_DS3_v2"},},
+                "nodes": {
+                    "node_types": {"node_type_id": "Standard_DS3_v2"},
+                },
             },
         },
         "libraries": [
@@ -116,7 +117,6 @@ def define_pyspark_pipe():
 
 
 @solid(
-    output_defs=[OutputDefinition(DataFrame)],
     required_resource_keys={"pyspark_step_launcher", "pyspark"},
 )
 def do_nothing_solid(_):
@@ -146,6 +146,10 @@ def test_local():
 @mock.patch("dagster_databricks.DatabricksPySparkStepLauncher.get_step_events")
 @mock.patch("dagster_databricks.databricks.DatabricksJobRunner.wait_for_run_to_complete")
 def test_pyspark_databricks(mock_wait, mock_get_step_events, mock_put_file, mock_submit_run):
+    mock_get_step_events.return_value = execute_pipeline(
+        pipeline=reconstructable(define_do_nothing_pipe), mode="local"
+    ).events_by_step_key["do_nothing_solid"]
+
     result = execute_pipeline(
         pipeline=reconstructable(define_do_nothing_pipe),
         mode="prod_s3",
@@ -180,7 +184,7 @@ def test_do_it_live_databricks_s3():
             "resources": {
                 "pyspark_step_launcher": {"config": BASE_DATABRICKS_PYSPARK_STEP_LAUNCHER_CONFIG},
             },
-            "storage": {
+            "intermediate_storage": {
                 "s3": {
                     "config": {
                         "s3_bucket": "dagster-databricks-tests",
@@ -221,7 +225,7 @@ def test_do_it_live_databricks_adls2():
                     }
                 },
             },
-            "storage": {
+            "intermediate_storage": {
                 "adls2": {
                     "config": {
                         "adls2_file_system": ADLS2_CONTAINER,
